// Composables
import { createRouter, createWebHistory } from "vue-router";
import { useConfigStore } from "@/store/config";
import keycloak from "@/plugins/keycloak"
import { useLoginUrlStore } from "@/store/login_url";
import staticConfig from "@/plugins/config"

const routes = [
  {
    path: "/",
    name: "home",
    meta: {
      auth: false,
    },
    // route level code-splitting
    // this generates a separate chunk (Home-[hash].js) for this route
    // which is lazy-loaded when the route is visited.
    component: () => import("@/views/libraries/List.vue"),
  },
  {
    path: "/editor",
    name:"editor",
    component: () => import("@/views/editor.vue"),
  },
  {
    path: "/auth/login",
    name: "login",
    component: () => import("@/views/auth/Login.vue"),
  },
  {
    path: "/libraries",
    name: "libraries",
    meta: {
      auth: true,
    },
    component: () => import("@/views/libraries/List.vue"),
  },
  {
    path: "/libraries/create",
    name: "libraries.create",
    meta: {
      auth: true,
    },
    component: () => import("@/views/libraries/Create.vue"),
  },
  {
    path: "/documents/:LibraryId/",
    name: "documents.list",
    component: () => import("@/views/documents/List.vue"),
  },
];

const router = createRouter({
  history: createWebHistory(process.env.BASE_URL),
  routes,
});

router.beforeEach((to, from) => {
  // get route name
  console.log(from.name, from.fullPath)

  const configStore = useConfigStore();
  const loginUrl = useLoginUrlStore();

  if (to.name != "login") {
    console.log("last visit:" + to.fullPath)
    // 设置最后访问 url
    loginUrl.setLastVisitUrl(to.fullPath);
  }

  // // 如果来自登录的 url，则跳转到最后访问的 url
  // if (from.name === "login") {
  //   const last_visit = loginUrl.getLastVisitUrl()

  //   if (last_visit) {
  //     console.log("跳转:" + last_visit)
  //     // window.location.href = last_visit
  //   }
 
  // }



  // if (to.matched.length === 0) {
  //   return router.push({ name: "errors.404" });
  // }

  if (to.meta.title) {
    document.title = to.meta.title + " - " + configStore.getAppName();
  } else {
    document.title = configStore.getAppName();
  }

  if (to.meta.auth) {
    if (!keycloak.authenticated && !staticConfig.devMode) {
      router.push({ name: "login" });
    }
  } else {
    document.title = configStore.getAppName();
  }

  return true;

});

export default router;
